/* parameters.cpp contains the functions for
 * computing and modifying
 * the set of parameters
 */

#ifndef parameters
#define parameters
#include "Eigen/Dense" 

using namespace Eigen;

/* computation of moment or statistics */
float mean(float *data_in, size_t N);
float compute_moment(float *data_in,int order ,size_t N);
float compute_variance(float *data_in, size_t N);
float compute_kurtosis(float *data_in, size_t N);
float compute_skewness(float *data_in, size_t N);
MatrixXf compute_cross_cor(float **list_data, size_t N_data, size_t N);
MatrixXf compute_cross_scale_cor(float **list_data_x, float **list_data_y, size_t N_data_x, size_t N_data_y, size_t N, int option);
MatrixXd compute_auto_cor(float *list_data, size_t nx, size_t ny, size_t Na);
float min(float *tab, size_t N);
float max(float *tab, size_t N);

/* modification of moment or statistics */
void mod_range(float *data, float m, float M, size_t N);
void mod_mean_variance(float *data, float mean_out, float var_out, size_t N);
void mod_skewness(float *data, float sk_out, size_t N);
void mod_kurtosis(float *data, float ku_out, size_t N);
void mod_cross_cor(float **list_data, const MatrixXf& auto_cor_out, size_t N);
int mod_cross_scale_cor(float **list_data_x, float **list_data_y, const MatrixXf& cross_cor_out, const MatrixXf& cross_scale_cor_out, size_t N);
void mod_auto_cor(float *data, const MatrixXd& auto_cor_out, size_t nx, size_t ny);
float *mod_marginal_statistics(float *data_in, size_t nx , size_t ny, size_t N);

#endif